Please see [https://docs.mlcommons.org/cm4mlops/scripts/Remote-automation/remote-run-commands](https://docs.mlcommons.org/cm4mlops/scripts/Remote-automation/remote-run-commands) for the documentation of this CM script.
